"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PackageUpdate(google.protobuf.message.Message):
    """Self update attempt event."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    PACKAGE_FIELD_NUMBER: builtins.int
    EXE_PATH_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Update dbt to this version (e.g. 1.2.3) [default: latest version]"""
    package: builtins.str
    """Package to update (e.g. dbt) [default: dbt]"""
    exe_path: builtins.str
    """The discovered path to the dbt executable"""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        package: builtins.str = ...,
        exe_path: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_exe_path", b"_exe_path", "exe_path", b"exe_path"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_exe_path", b"_exe_path", "exe_path", b"exe_path", "package", b"package", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_exe_path", b"_exe_path"]) -> typing.Literal["exe_path"] | None: ...

Global___PackageUpdate: typing_extensions.TypeAlias = PackageUpdate



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ShowDataOutputFormat:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ShowDataOutputFormatEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ShowDataOutputFormat.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SHOW_DATA_OUTPUT_FORMAT_UNSPECIFIED: _ShowDataOutputFormat.ValueType  # 0
    SHOW_DATA_OUTPUT_FORMAT_TEXT: _ShowDataOutputFormat.ValueType  # 1
    SHOW_DATA_OUTPUT_FORMAT_CSV: _ShowDataOutputFormat.ValueType  # 2
    SHOW_DATA_OUTPUT_FORMAT_TSV: _ShowDataOutputFormat.ValueType  # 3
    SHOW_DATA_OUTPUT_FORMAT_JSON: _ShowDataOutputFormat.ValueType  # 4
    SHOW_DATA_OUTPUT_FORMAT_NDJSON: _ShowDataOutputFormat.ValueType  # 5
    SHOW_DATA_OUTPUT_FORMAT_YML: _ShowDataOutputFormat.ValueType  # 6

class ShowDataOutputFormat(_ShowDataOutputFormat, metaclass=_ShowDataOutputFormatEnumTypeWrapper):
    """Output format for list command"""

SHOW_DATA_OUTPUT_FORMAT_UNSPECIFIED: ShowDataOutputFormat.ValueType  # 0
SHOW_DATA_OUTPUT_FORMAT_TEXT: ShowDataOutputFormat.ValueType  # 1
SHOW_DATA_OUTPUT_FORMAT_CSV: ShowDataOutputFormat.ValueType  # 2
SHOW_DATA_OUTPUT_FORMAT_TSV: ShowDataOutputFormat.ValueType  # 3
SHOW_DATA_OUTPUT_FORMAT_JSON: ShowDataOutputFormat.ValueType  # 4
SHOW_DATA_OUTPUT_FORMAT_NDJSON: ShowDataOutputFormat.ValueType  # 5
SHOW_DATA_OUTPUT_FORMAT_YML: ShowDataOutputFormat.ValueType  # 6
Global___ShowDataOutputFormat: typing_extensions.TypeAlias = ShowDataOutputFormat

@typing.final
class ShowDataOutput(google.protobuf.message.Message):
    """Event emitted when displaying inline data (e.g., from show command).
    This event replaces the dbt-core ShowNode event (Q041) for inline data display.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_FORMAT_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    IS_INLINE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    COLUMNS_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    output_format: Global___ShowDataOutputFormat.ValueType
    """Format of the output"""
    content: builtins.str
    """The data in the specified format (e.g., pretty-printed table)"""
    node_name: builtins.str
    """Name of the node being shown (e.g., "my_model" or "inline")"""
    is_inline: builtins.bool
    """Whether this is an inline/ad-hoc query (true) or a defined node (false)"""
    unique_id: builtins.str
    """The unique_id of the node being shown (e.g., "model.my_project.my_model").
    Unset for ad-hoc queries
    """
    dbt_core_event_code: builtins.str
    """Legacy dbt core event code for backward compatibility (always "Q041")"""
    @property
    def columns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Column names for the data"""

    def __init__(
        self,
        *,
        output_format: Global___ShowDataOutputFormat.ValueType = ...,
        content: builtins.str = ...,
        node_name: builtins.str = ...,
        is_inline: builtins.bool = ...,
        unique_id: builtins.str | None = ...,
        columns: collections.abc.Iterable[builtins.str] | None = ...,
        dbt_core_event_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "unique_id", b"unique_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_unique_id", b"_unique_id", "columns", b"columns", "content", b"content", "dbt_core_event_code", b"dbt_core_event_code", "is_inline", b"is_inline", "node_name", b"node_name", "output_format", b"output_format", "unique_id", b"unique_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_unique_id", b"_unique_id"]) -> typing.Literal["unique_id"] | None: ...

Global___ShowDataOutput: typing_extensions.TypeAlias = ShowDataOutput



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/artifact/artifact.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=dbtlabs/proto/public/v1/events/fusion/artifact/artifact.proto\x12 v1.public.events.fusion.artifact\"o\n\x0f\x41rtifactWritten\x12\x15\n\rrelative_path\x18\x01 \x01(\t\x12\x45\n\rartifact_type\x18\x02 \x01(\x0e\x32..v1.public.events.fusion.artifact.ArtifactType*\x89\x01\n\x0c\x41rtifactType\x12\x1d\n\x19\x41RTIFACT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x41RTIFACT_TYPE_MANIFEST\x10\x01\x12#\n\x1f\x41RTIFACT_TYPE_SEMANTIC_MANIFEST\x10\x02\x12\x19\n\x15\x41RTIFACT_TYPE_CATALOG\x10\x03\x42\x43ZAgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/artifactb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.artifact.artifact_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/artifact'
  _globals['_ARTIFACTTYPE']._serialized_start=213
  _globals['_ARTIFACTTYPE']._serialized_end=350
  _globals['_ARTIFACTWRITTEN']._serialized_start=99
  _globals['_ARTIFACTWRITTEN']._serialized_end=210
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OnboardingScreenShown(google.protobuf.message.Message):
    """Onboarding step event."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCREEN_FIELD_NUMBER: builtins.int
    screen: dbtlabs.proto.public.v1.events.fusion_pb2.OnboardingScreen.ValueType
    """Onboarding screen identifier"""
    def __init__(
        self,
        *,
        screen: dbtlabs.proto.public.v1.events.fusion_pb2.OnboardingScreen.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["screen", b"screen"]) -> None: ...

Global___OnboardingScreenShown: typing_extensions.TypeAlias = OnboardingScreenShown



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2
import dbtlabs.proto.public.v1.events.vortex_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HandoffFrom:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HandoffFromEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HandoffFrom.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HANDOFF_FROM_UNSPECIFIED: _HandoffFrom.ValueType  # 0
    HANDOFF_FROM_CATALOG: _HandoffFrom.ValueType  # 1

class HandoffFrom(_HandoffFrom, metaclass=_HandoffFromEnumTypeWrapper):
    """As of 2025/05, enums are not handled properly with Vortex
    so we will be documenting them but not using them in the proto
    """

HANDOFF_FROM_UNSPECIFIED: HandoffFrom.ValueType  # 0
HANDOFF_FROM_CATALOG: HandoffFrom.ValueType  # 1
Global___HandoffFrom: typing_extensions.TypeAlias = HandoffFrom

class _HandoffTo:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HandoffToEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HandoffTo.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HANDOFF_TO_UNSPECIFIED: _HandoffTo.ValueType  # 0
    HANDOFF_TO_CATALOG: _HandoffTo.ValueType  # 1
    HANDOFF_TO_IDE: _HandoffTo.ValueType  # 2
    HANDOFF_TO_CANVAS: _HandoffTo.ValueType  # 3
    HANDOFF_TO_INSIGHTS: _HandoffTo.ValueType  # 4

class HandoffTo(_HandoffTo, metaclass=_HandoffToEnumTypeWrapper): ...

HANDOFF_TO_UNSPECIFIED: HandoffTo.ValueType  # 0
HANDOFF_TO_CATALOG: HandoffTo.ValueType  # 1
HANDOFF_TO_IDE: HandoffTo.ValueType  # 2
HANDOFF_TO_CANVAS: HandoffTo.ValueType  # 3
HANDOFF_TO_INSIGHTS: HandoffTo.ValueType  # 4
Global___HandoffTo: typing_extensions.TypeAlias = HandoffTo

class _HandoffAssetType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HandoffAssetTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HandoffAssetType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HANDOFF_ASSET_TYPE_UNSPECIFIED: _HandoffAssetType.ValueType  # 0
    HANDOFF_ASSET_TYPE_DBT_MODEL: _HandoffAssetType.ValueType  # 1
    HANDOFF_ASSET_TYPE_DBT_SOURCE: _HandoffAssetType.ValueType  # 2
    HANDOFF_ASSET_TYPE_DBT_SNAPSHOT: _HandoffAssetType.ValueType  # 3
    HANDOFF_ASSET_TYPE_DBT_SEED: _HandoffAssetType.ValueType  # 4
    HANDOFF_ASSET_TYPE_DBT_METRIC: _HandoffAssetType.ValueType  # 5
    HANDOFF_ASSET_TYPE_DBT_SAVED_QUERY: _HandoffAssetType.ValueType  # 6
    HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_TABLE: _HandoffAssetType.ValueType  # 7
    HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_VIEW: _HandoffAssetType.ValueType  # 8

class HandoffAssetType(_HandoffAssetType, metaclass=_HandoffAssetTypeEnumTypeWrapper): ...

HANDOFF_ASSET_TYPE_UNSPECIFIED: HandoffAssetType.ValueType  # 0
HANDOFF_ASSET_TYPE_DBT_MODEL: HandoffAssetType.ValueType  # 1
HANDOFF_ASSET_TYPE_DBT_SOURCE: HandoffAssetType.ValueType  # 2
HANDOFF_ASSET_TYPE_DBT_SNAPSHOT: HandoffAssetType.ValueType  # 3
HANDOFF_ASSET_TYPE_DBT_SEED: HandoffAssetType.ValueType  # 4
HANDOFF_ASSET_TYPE_DBT_METRIC: HandoffAssetType.ValueType  # 5
HANDOFF_ASSET_TYPE_DBT_SAVED_QUERY: HandoffAssetType.ValueType  # 6
HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_TABLE: HandoffAssetType.ValueType  # 7
HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_VIEW: HandoffAssetType.ValueType  # 8
Global___HandoffAssetType: typing_extensions.TypeAlias = HandoffAssetType

@typing.final
class Handoff(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    CONTEXT_FIELD_NUMBER: builtins.int
    HANDOFF_FROM_FIELD_NUMBER: builtins.int
    HANDOFF_TO_FIELD_NUMBER: builtins.int
    IS_FINAL_HANDOFF_ACTION_FIELD_NUMBER: builtins.int
    HANDOFF_ACTION_FIELD_NUMBER: builtins.int
    ASSET_TYPE_FIELD_NUMBER: builtins.int
    handoff_from: builtins.str
    """There are fields below that would have been defined as enums but Vortex doesn't support enums well

    originating feature; see HandoffFrom for possible values
    """
    handoff_to: builtins.str
    """target feature; see HandoffTo for possible values"""
    is_final_handoff_action: builtins.bool
    """true if this completes the handoff experience"""
    handoff_action: builtins.str
    """applicable only if a handoff has different types, ex. 'Catalog -> Canvas' handoff can 'create' or 'edit'"""
    asset_type: builtins.str
    """asset type of resource being handed off; see HandoffAssetType for possible values"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """Server enrichment for this event"""

    @property
    def context(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext:
        """dbt Cloud Context around this request"""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        context: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        handoff_from: builtins.str = ...,
        handoff_to: builtins.str = ...,
        is_final_handoff_action: builtins.bool = ...,
        handoff_action: builtins.str = ...,
        asset_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["context", b"context", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["asset_type", b"asset_type", "context", b"context", "enrichment", b"enrichment", "handoff_action", b"handoff_action", "handoff_from", b"handoff_from", "handoff_to", b"handoff_to", "is_final_handoff_action", b"is_final_handoff_action"]) -> None: ...

Global___Handoff: typing_extensions.TypeAlias = Handoff



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x12*v1.public.common.vortex_telemetry_contexts\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xd1\x02\n\x1eVortexTelemetryDbtCloudContext\x12\x10\n\x08\x65vent_id\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x01(\t\x12\"\n\x1asnowplow_domain_session_id\x18\x03 \x01(\t\x12\x1f\n\x17snowplow_domain_user_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\x12\x14\n\x0creferrer_url\x18\x06 \x01(\t\x12\x1c\n\x14\x64\x62t_cloud_account_id\x18\x07 \x01(\t\x12$\n\x1c\x64\x62t_cloud_account_identifier\x18\x08 \x01(\t\x12\x1c\n\x14\x64\x62t_cloud_project_id\x18\t \x01(\t\x12 \n\x18\x64\x62t_cloud_environment_id\x18\n \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\x0b \x01(\tBMZKgithub.com/dbt-labs/proto-golang/v1/public/common/vortex_telemetry_contextsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZKgithub.com/dbt-labs/proto-golang/v1/public/common/vortex_telemetry_contexts'
  _globals['_VORTEXTELEMETRYDBTCLOUDCONTEXT']._serialized_start=156
  _globals['_VORTEXTELEMETRYDBTCLOUDCONTEXT']._serialized_end=493
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import dbtlabs.proto.public.v1.events.vortex_pb2
import dbtlabs.proto.public.v1.fields.vscode_types_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ExtensionActivated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    OS_NAME_FIELD_NUMBER: builtins.int
    OS_VERSION_FIELD_NUMBER: builtins.int
    INIT_SUCCESS_FIELD_NUMBER: builtins.int
    INIT_ERROR_FIELD_NUMBER: builtins.int
    INIT_ERROR_DETAIL_FIELD_NUMBER: builtins.int
    INIT_DURATION_MS_FIELD_NUMBER: builtins.int
    IS_LSP_INSTALLED_FIELD_NUMBER: builtins.int
    IS_FUSION_INSTALLED_FIELD_NUMBER: builtins.int
    DBT_VERSION_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    MODELS_COUNT_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    os_name: builtins.str
    """os name"""
    os_version: builtins.str
    """os version"""
    init_success: builtins.bool
    """whether the extension was able to initialize successfully"""
    init_error: builtins.str
    """type of initializion error, if an error occurred at initialization"""
    init_error_detail: builtins.str
    """detailed error message, if an error occurred at initialization"""
    init_duration_ms: builtins.int
    """duration of the initialization in milliseconds"""
    is_lsp_installed: builtins.bool
    """does the user have LSP installed"""
    is_fusion_installed: builtins.bool
    """does the user have fusion installed"""
    dbt_version: builtins.str
    """the version of dbt used in the project"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    models_count: builtins.int
    """project models count"""
    adapter_type: builtins.str
    """the type of adapter used in the project (snowflake, bigquery, etc)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        os_name: builtins.str = ...,
        os_version: builtins.str = ...,
        init_success: builtins.bool = ...,
        init_error: builtins.str = ...,
        init_error_detail: builtins.str = ...,
        init_duration_ms: builtins.int = ...,
        is_lsp_installed: builtins.bool = ...,
        is_fusion_installed: builtins.bool = ...,
        dbt_version: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        models_count: builtins.int = ...,
        adapter_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "dbt_version", b"dbt_version", "editor", b"editor", "enrichment", b"enrichment", "init_duration_ms", b"init_duration_ms", "init_error", b"init_error", "init_error_detail", b"init_error_detail", "init_success", b"init_success", "is_fusion_installed", b"is_fusion_installed", "is_lsp_installed", b"is_lsp_installed", "models_count", b"models_count", "os_name", b"os_name", "os_version", b"os_version", "user", b"user"]) -> None: ...

Global___ExtensionActivated: typing_extensions.TypeAlias = ExtensionActivated

@typing.final
class ExtensionLspCompile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    ADAPTER_UNIQUE_ID_FIELD_NUMBER: builtins.int
    DBT_VERSION_FIELD_NUMBER: builtins.int
    COMPILE_SUCCESS_FIELD_NUMBER: builtins.int
    ERRORS_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    COMPILE_TYPE_FIELD_NUMBER: builtins.int
    MODELS_COUNT_FIELD_NUMBER: builtins.int
    USER_INITIATED_FIELD_NUMBER: builtins.int
    COMPILE_CAUSE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """this is the hash of the project's name, used for anonymized telemetry"""
    adapter_type: builtins.str
    """the type of adapter used in the project (snowflake, bigquery, etc)"""
    adapter_unique_id: builtins.str
    """the unique id of the adapter used in the active profile eg. md5(hostname)"""
    dbt_version: builtins.str
    """the version of dbt used in the project"""
    compile_success: builtins.bool
    """Indicates whether the compile was successful"""
    duration_ms: builtins.int
    """duration of the compile in milliseconds"""
    compile_type: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileType.ValueType
    """the type of compile"""
    models_count: builtins.int
    """project models count"""
    user_initiated: builtins.bool
    """True if the compile was triggered by a user action (ie. saving a file)"""
    compile_cause: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileCause.ValueType
    """The event that triggered the compile"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    @property
    def errors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileError]: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        project_id: builtins.str = ...,
        adapter_type: builtins.str = ...,
        adapter_unique_id: builtins.str = ...,
        dbt_version: builtins.str = ...,
        compile_success: builtins.bool = ...,
        errors: collections.abc.Iterable[dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileError] | None = ...,
        duration_ms: builtins.int = ...,
        compile_type: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileType.ValueType = ...,
        models_count: builtins.int = ...,
        user_initiated: builtins.bool = ...,
        compile_cause: dbtlabs.proto.public.v1.fields.vscode_types_pb2.CompileCause.ValueType = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "adapter_unique_id", b"adapter_unique_id", "compile_cause", b"compile_cause", "compile_success", b"compile_success", "compile_type", b"compile_type", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "dbt_version", b"dbt_version", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "errors", b"errors", "models_count", b"models_count", "project_id", b"project_id", "user", b"user", "user_initiated", b"user_initiated"]) -> None: ...

Global___ExtensionLspCompile: typing_extensions.TypeAlias = ExtensionLspCompile

@typing.final
class ExtensionUserStateChange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    CHANGED_TO_STATE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    changed_to_state: dbtlabs.proto.public.v1.fields.vscode_types_pb2.UserState.ValueType
    """the state the user changed to"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        changed_to_state: dbtlabs.proto.public.v1.fields.vscode_types_pb2.UserState.ValueType = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["changed_to_state", b"changed_to_state", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionUserStateChange: typing_extensions.TypeAlias = ExtensionUserStateChange

@typing.final
class ExtensionCtePreview(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionCtePreview: typing_extensions.TypeAlias = ExtensionCtePreview

@typing.final
class ExtensionLineageTabClicked(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionLineageTabClicked: typing_extensions.TypeAlias = ExtensionLineageTabClicked

@typing.final
class ExtensionColumnLineage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionColumnLineage: typing_extensions.TypeAlias = ExtensionColumnLineage

@typing.final
class ExtensionShowCompiledFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionShowCompiledFile: typing_extensions.TypeAlias = ExtensionShowCompiledFile

@typing.final
class ExtensionModelRename(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionModelRename: typing_extensions.TypeAlias = ExtensionModelRename

@typing.final
class ExtensionColumnRename(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> None: ...

Global___ExtensionColumnRename: typing_extensions.TypeAlias = ExtensionColumnRename

@typing.final
class ExtensionUsedBuildMenu(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SELECTED_COMMAND_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    selected_command: builtins.str
    """the command that the user selected"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        selected_command: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "selected_command", b"selected_command", "user", b"user"]) -> None: ...

Global___ExtensionUsedBuildMenu: typing_extensions.TypeAlias = ExtensionUsedBuildMenu

@typing.final
class ExtensionGetSupportPopupShown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being offered"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportPopupShown: typing_extensions.TypeAlias = ExtensionGetSupportPopupShown

@typing.final
class ExtensionGetSupportClicked(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support that was clicked"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportClicked: typing_extensions.TypeAlias = ExtensionGetSupportClicked

@typing.final
class ExtensionGetSupportFormShown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being offered"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportFormShown: typing_extensions.TypeAlias = ExtensionGetSupportFormShown

@typing.final
class ExtensionGetSupportUnverifiedNoticeShown(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being offered"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportUnverifiedNoticeShown: typing_extensions.TypeAlias = ExtensionGetSupportUnverifiedNoticeShown

@typing.final
class ExtensionGetSupportFormSubmitted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support that was submitted"""
    success: builtins.bool
    """whether the submission was successful"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        success: builtins.bool = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "success", b"success", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportFormSubmitted: typing_extensions.TypeAlias = ExtensionGetSupportFormSubmitted

@typing.final
class ExtensionGetSupportFormCancelled(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support being cancelled"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportFormCancelled: typing_extensions.TypeAlias = ExtensionGetSupportFormCancelled

@typing.final
class ExtensionGetSupportPanelClosed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    SUPPORT_TYPE_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    support_type: builtins.str
    """the type of support panel that was closed"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        support_type: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "support_type", b"support_type", "user", b"user"]) -> None: ...

Global___ExtensionGetSupportPanelClosed: typing_extensions.TypeAlias = ExtensionGetSupportPanelClosed

@typing.final
class ExtensionCompareViewed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "user", b"user"]) -> None: ...

Global___ExtensionCompareViewed: typing_extensions.TypeAlias = ExtensionCompareViewed

@typing.final
class ExtensionCompareStarted(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    COMPARE_ID_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    compare_id: builtins.str
    """anonymized identifier for this compare session"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        compare_id: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compare_id", b"compare_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "user", b"user"]) -> None: ...

Global___ExtensionCompareStarted: typing_extensions.TypeAlias = ExtensionCompareStarted

@typing.final
class ExtensionCompareFinished(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    COMPARE_ID_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    COMPARE_SUCCESS_FIELD_NUMBER: builtins.int
    FAILURE_REASON_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    compare_id: builtins.str
    """anonymized identifier for this compare session"""
    duration_ms: builtins.int
    """duration of the compare operation in milliseconds"""
    compare_success: builtins.bool
    """whether the compare operation completed successfully"""
    failure_reason: builtins.str
    """sanitized description of the failure, if any"""
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        compare_id: builtins.str = ...,
        duration_ms: builtins.int = ...,
        compare_success: builtins.bool = ...,
        failure_reason: builtins.str = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compare_id", b"compare_id", "compare_success", b"compare_success", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "failure_reason", b"failure_reason", "user", b"user"]) -> None: ...

Global___ExtensionCompareFinished: typing_extensions.TypeAlias = ExtensionCompareFinished

@typing.final
class ExtensionRegistrationMessageDismissed(google.protobuf.message.Message):
    """Emited if the user dismiss a message prompting them to register the extension?"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationMessageDismissed: typing_extensions.TypeAlias = ExtensionRegistrationMessageDismissed

@typing.final
class ExtensionRegisterStarted(google.protobuf.message.Message):
    """Emitted if the user starts the registration flow. There are several UI affordances to do this."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    TRIGGER_METHOD_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType
    """which registration path will be used"""
    correlation_id: builtins.str
    """identifier to correlate related registration events"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "trigger_method", b"trigger_method", "user", b"user"]) -> None: ...

Global___ExtensionRegisterStarted: typing_extensions.TypeAlias = ExtensionRegisterStarted

@typing.final
class ExtensionRegistrationUrlAttempted(google.protobuf.message.Message):
    """In vscode, extensions cannot automatically open external URLs
    Instead, vscode shows the user a modal with the URL
    The user can pick Open, Trust Domain, Copy, or Cancel
    Open or Trust Domain result in the URL opening, and url_opened will be true
    Cancel or Copy result in url_opened false
    If the user copied the URL, they may paste it into a browser to continue registration
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    URL_OPENED_FIELD_NUMBER: builtins.int
    OAUTH_PARAMS_INCLUDED_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    url_opened: builtins.bool
    """whether the user opened the URL (Open/Trust = true, Cancel/Copy = false)"""
    oauth_params_included: builtins.bool
    """whether oauth parameters were included in the URL"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        url_opened: builtins.bool = ...,
        oauth_params_included: builtins.bool = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "oauth_params_included", b"oauth_params_included", "url_opened", b"url_opened", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationUrlAttempted: typing_extensions.TypeAlias = ExtensionRegistrationUrlAttempted

@typing.final
class ExtensionRegistrationCompleted(google.protobuf.message.Message):
    """Emitted when the user successfully completes registration"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    REGISTRATION_METHOD_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_HOST_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType
    """the actual registration method used"""
    duration_ms: builtins.int
    """duration of the registration flow in milliseconds"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    account_id: builtins.str
    """dbt Cloud account ID the user registered with"""
    user_id: builtins.str
    """dbt Cloud user ID for the registered user"""
    account_host: builtins.str
    """dbt Cloud hostname (e.g., cloud.getdbt.com)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType = ...,
        duration_ms: builtins.int = ...,
        correlation_id: builtins.str = ...,
        account_id: builtins.str = ...,
        user_id: builtins.str = ...,
        account_host: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["account_host", b"account_host", "account_id", b"account_id", "correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "registration_method", b"registration_method", "user", b"user", "user_id", b"user_id"]) -> None: ...

Global___ExtensionRegistrationCompleted: typing_extensions.TypeAlias = ExtensionRegistrationCompleted

@typing.final
class ExtensionRegistrationTimedOut(google.protobuf.message.Message):
    """Once a user starts registration, they must complete it within 10 minutes
    After 10 minutes, the auth server shuts down and we emit this event
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    TRIGGER_METHOD_FIELD_NUMBER: builtins.int
    TIMEOUT_DURATION_MS_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType
    """the registration trigger method that timed out (dbt_cloud.yml or web)"""
    timeout_duration_ms: builtins.int
    """duration until timeout in milliseconds"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        trigger_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationTriggerMethod.ValueType = ...,
        timeout_duration_ms: builtins.int = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "editor", b"editor", "enrichment", b"enrichment", "event_id", b"event_id", "timeout_duration_ms", b"timeout_duration_ms", "trigger_method", b"trigger_method", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationTimedOut: typing_extensions.TypeAlias = ExtensionRegistrationTimedOut

@typing.final
class ExtensionRegistrationErrored(google.protobuf.message.Message):
    """Emitted when an error occurs during registration
    These are most likely to be caused by issues in code (bugs, unanticipated cases, regressiones)
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EDITOR_FIELD_NUMBER: builtins.int
    USER_FIELD_NUMBER: builtins.int
    DBT_LOCAL_COOKIE_USER_ID_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    REGISTRATION_METHOD_FIELD_NUMBER: builtins.int
    ERROR_TYPE_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    DURATION_MS_FIELD_NUMBER: builtins.int
    CORRELATION_ID_FIELD_NUMBER: builtins.int
    dbt_local_cookie_user_id: builtins.str
    """the anonymous user id stored at ~/.dbt/.user.yml"""
    event_id: builtins.str
    """UUID to uniquely identify the event"""
    registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType
    """the registration method that errored (use UNSPECIFIED if not yet known)"""
    error_type: builtins.str
    """type/category of error that occurred"""
    error_message: builtins.str
    """sanitized error message (no PII)"""
    duration_ms: builtins.int
    """duration until error in milliseconds"""
    correlation_id: builtins.str
    """identifier to correlate related registration events (matches RegisterClicked)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def editor(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor: ...
    @property
    def user(self) -> dbtlabs.proto.public.v1.fields.vscode_types_pb2.User: ...
    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        editor: dbtlabs.proto.public.v1.fields.vscode_types_pb2.Editor | None = ...,
        user: dbtlabs.proto.public.v1.fields.vscode_types_pb2.User | None = ...,
        dbt_local_cookie_user_id: builtins.str = ...,
        event_id: builtins.str = ...,
        registration_method: dbtlabs.proto.public.v1.fields.vscode_types_pb2.RegistrationMethod.ValueType = ...,
        error_type: builtins.str = ...,
        error_message: builtins.str = ...,
        duration_ms: builtins.int = ...,
        correlation_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["editor", b"editor", "enrichment", b"enrichment", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["correlation_id", b"correlation_id", "dbt_local_cookie_user_id", b"dbt_local_cookie_user_id", "duration_ms", b"duration_ms", "editor", b"editor", "enrichment", b"enrichment", "error_message", b"error_message", "error_type", b"error_type", "event_id", b"event_id", "registration_method", b"registration_method", "user", b"user"]) -> None: ...

Global___ExtensionRegistrationErrored: typing_extensions.TypeAlias = ExtensionRegistrationErrored



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/invocation/invocation.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.process import process_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_process_dot_process__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAdbtlabs/proto/public/v1/events/fusion/invocation/invocation.proto\x12\"v1.public.events.fusion.invocation\x1a;dbtlabs/proto/public/v1/events/fusion/process/process.proto\"\xda\x03\n\x11InvocationMetrics\x12\x19\n\x0ctotal_errors\x18\x01 \x01(\x04H\x00\x88\x01\x01\x12\x1b\n\x0etotal_warnings\x18\x02 \x01(\x04H\x01\x88\x01\x01\x12 \n\x13\x61utofix_suggestions\x18\x03 \x01(\x04H\x02\x88\x01\x01\x12\x63\n\x10node_type_counts\x18\x04 \x03(\x0b\x32I.v1.public.events.fusion.invocation.InvocationMetrics.NodeTypeCountsEntry\x12^\n\rstatus_counts\x18\x05 \x03(\x0b\x32G.v1.public.events.fusion.invocation.InvocationMetrics.StatusCountsEntry\x1a\x35\n\x13NodeTypeCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x33\n\x11StatusCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x42\x0f\n\r_total_errorsB\x11\n\x0f_total_warningsB\x16\n\x14_autofix_suggestions\"\xc9\x06\n\x12InvocationEvalArgs\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x19\n\x0cprofiles_dir\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15packages_install_path\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06target\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07profile\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x0c\n\x04vars\x18\x06 \x01(\t\x12\x12\n\x05limit\x18\x07 \x01(\x04H\x04\x88\x01\x01\x12\x18\n\x0bnum_threads\x18\x08 \x01(\x04H\x05\x88\x01\x01\x12\x15\n\x08selector\x18\t \x01(\tH\x06\x88\x01\x01\x12\x0e\n\x06select\x18\n \x03(\t\x12\x0f\n\x07\x65xclude\x18\x0b \x03(\t\x12\x1f\n\x12indirect_selection\x18\x0c \x01(\tH\x07\x88\x01\x01\x12\x13\n\x0boutput_keys\x18\r \x03(\t\x12\x16\n\x0eresource_types\x18\x0e \x03(\t\x12\x1e\n\x16\x65xclude_resource_types\x18\x0f \x03(\t\x12\x12\n\x05\x64\x65\x62ug\x18\x10 \x01(\x08H\x08\x88\x01\x01\x12\x17\n\nlog_format\x18\x11 \x01(\tH\t\x88\x01\x01\x12\x16\n\tlog_level\x18\x12 \x01(\tH\n\x88\x01\x01\x12\x15\n\x08log_path\x18\x13 \x01(\tH\x0b\x88\x01\x01\x12\x18\n\x0btarget_path\x18\x14 \x01(\tH\x0c\x88\x01\x01\x12\x18\n\x0bproject_dir\x18\x15 \x01(\tH\r\x88\x01\x01\x12\x12\n\x05quiet\x18\x16 \x01(\x08H\x0e\x88\x01\x01\x12\x17\n\nwrite_json\x18\x17 \x01(\x08H\x0f\x88\x01\x01\x12\x1a\n\rwrite_catalog\x18\x18 \x01(\x08H\x10\x88\x01\x01\x42\x0f\n\r_profiles_dirB\x18\n\x16_packages_install_pathB\t\n\x07_targetB\n\n\x08_profileB\x08\n\x06_limitB\x0e\n\x0c_num_threadsB\x0b\n\t_selectorB\x15\n\x13_indirect_selectionB\x08\n\x06_debugB\r\n\x0b_log_formatB\x0c\n\n_log_levelB\x0b\n\t_log_pathB\x0e\n\x0c_target_pathB\x0e\n\x0c_project_dirB\x08\n\x06_quietB\r\n\x0b_write_jsonB\x10\n\x0e_write_catalog\"\xbb\x02\n\nInvocation\x12\x15\n\rinvocation_id\x18\x01 \x01(\t\x12\x13\n\x0braw_command\x18\x02 \x01(\t\x12I\n\teval_args\x18\x03 \x01(\x0b\x32\x36.v1.public.events.fusion.invocation.InvocationEvalArgs\x12>\n\x0cprocess_info\x18\x04 \x01(\x0b\x32(.v1.public.events.fusion.process.Process\x12\x46\n\x07metrics\x18\x05 \x01(\x0b\x32\x35.v1.public.events.fusion.invocation.InvocationMetrics\x12\x1b\n\x0eparent_span_id\x18\x06 \x01(\x04H\x00\x88\x01\x01\x42\x11\n\x0f_parent_span_idBEZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/invocationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.invocation.invocation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/dbt-labs/proto-golang/v1/public/events/fusion/invocation'
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._loaded_options = None
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._loaded_options = None
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_INVOCATIONMETRICS']._serialized_start=167
  _globals['_INVOCATIONMETRICS']._serialized_end=641
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._serialized_start=475
  _globals['_INVOCATIONMETRICS_NODETYPECOUNTSENTRY']._serialized_end=528
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._serialized_start=530
  _globals['_INVOCATIONMETRICS_STATUSCOUNTSENTRY']._serialized_end=581
  _globals['_INVOCATIONEVALARGS']._serialized_start=644
  _globals['_INVOCATIONEVALARGS']._serialized_end=1485
  _globals['_INVOCATION']._serialized_start=1488
  _globals['_INVOCATION']._serialized_end=1803
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Process(google.protobuf.message.Message):
    """Process-wide attributes for a telemetry-emitting process."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    HOST_OS_FIELD_NUMBER: builtins.int
    HOST_ARCH_FIELD_NUMBER: builtins.int
    package: builtins.str
    """Name of the emitting package, e.g. "dbt" or "dbt-lsp"."""
    version: builtins.str
    """Version of the emitting package, e.g. "v2.0.0"."""
    host_os: builtins.str
    """Host operating system, e.g. "linux", "darwin", "windows"."""
    host_arch: builtins.str
    """Host architecture, e.g. "x86_64", "aarch64"."""
    def __init__(
        self,
        *,
        package: builtins.str = ...,
        version: builtins.str = ...,
        host_os: builtins.str = ...,
        host_arch: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_arch", b"host_arch", "host_os", b"host_os", "package", b"package", "version", b"version"]) -> None: ...

Global___Process: typing_extensions.TypeAlias = Process



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.internal.extension_dict
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _VortexIcebergNamespace:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VortexIcebergNamespaceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VortexIcebergNamespace.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    VORTEX_ICEBERG_NAMESPACE_UNSPECIFIED: _VortexIcebergNamespace.ValueType  # 0
    """owner: Zach Brown"""
    VORTEX_ICEBERG_NAMESPACE_COST_MONITORING: _VortexIcebergNamespace.ValueType  # 1
    """owner: Brandon Cole"""
    VORTEX_ICEBERG_NAMESPACE_FUSION: _VortexIcebergNamespace.ValueType  # 2
    """owner: Lukas Schulte"""
    VORTEX_ICEBERG_NAMESPACE_TELEMETRY: _VortexIcebergNamespace.ValueType  # 3
    """owner: Zach Brown"""
    VORTEX_ICEBERG_NAMESPACE_DLQ: _VortexIcebergNamespace.ValueType  # 4
    """owner: Zach Brown
    This is strictly for dead letter queue events and internal use only.
    """
    VORTEX_ICEBERG_NAMESPACE_MANTLE: _VortexIcebergNamespace.ValueType  # 5
    """owner: Zeeshan Qureshi"""
    VORTEX_ICEBERG_NAMESPACE_CODEX: _VortexIcebergNamespace.ValueType  # 6
    """owner: Vadim Rybak"""

class VortexIcebergNamespace(_VortexIcebergNamespace, metaclass=_VortexIcebergNamespaceEnumTypeWrapper):
    """the set of valid namespaces in the iceberg catalog."""

VORTEX_ICEBERG_NAMESPACE_UNSPECIFIED: VortexIcebergNamespace.ValueType  # 0
"""owner: Zach Brown"""
VORTEX_ICEBERG_NAMESPACE_COST_MONITORING: VortexIcebergNamespace.ValueType  # 1
"""owner: Brandon Cole"""
VORTEX_ICEBERG_NAMESPACE_FUSION: VortexIcebergNamespace.ValueType  # 2
"""owner: Lukas Schulte"""
VORTEX_ICEBERG_NAMESPACE_TELEMETRY: VortexIcebergNamespace.ValueType  # 3
"""owner: Zach Brown"""
VORTEX_ICEBERG_NAMESPACE_DLQ: VortexIcebergNamespace.ValueType  # 4
"""owner: Zach Brown
This is strictly for dead letter queue events and internal use only.
"""
VORTEX_ICEBERG_NAMESPACE_MANTLE: VortexIcebergNamespace.ValueType  # 5
"""owner: Zeeshan Qureshi"""
VORTEX_ICEBERG_NAMESPACE_CODEX: VortexIcebergNamespace.ValueType  # 6
"""owner: Vadim Rybak"""
Global___VortexIcebergNamespace: typing_extensions.TypeAlias = VortexIcebergNamespace

VORTEX_NAMESPACE_FIELD_NUMBER: builtins.int
VORTEX_TABLE_NAME_FIELD_NUMBER: builtins.int
VORTEX_PARTITION_FIELD_FIELD_NUMBER: builtins.int
VORTEX_WRITE_TO_ICEBERG_FIELD_NUMBER: builtins.int
VORTEX_ENABLED_FIELD_NUMBER: builtins.int
vortex_namespace: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, Global___VortexIcebergNamespace.ValueType]
"""the namespace to write within the iceberg catalog. it must
be one of the valid values above. adding a new namespace
requires an approval from the vortex team.

if not set, this will default to a namespace called `catchall`.
this is not called `default` because that is a common reserved
keyword in many query engines.
"""
vortex_table_name: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.str]
"""the table name to write within the specified namespace.
this should only be set in rare circumstances, such as
when a proto is renamed but we want to
"""
vortex_partition_field: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.int]
"""the field identifier in the message that vortex should use
to partition the message. by default, this will be the
`vortex_event_created_at` field, to ensure that we correctly
partition late-arriving events.

this means that when querying the iceberg table downstream,
queries will be _much_ more efficient when filtering on this
field.

if you override this, it's recommended that you choose a
timestamp field.
"""
vortex_write_to_iceberg: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
"""if true, this event should be written to the iceberg table.
if false, this event should be ignored.
default behavior is to treat as true.
"""
vortex_enabled: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.MessageOptions, builtins.bool]
"""if true, this event can be ingested by vortex.
if false, vortex will not accept this event or create a table.
default behavior is to treat as false.
"""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/metadata_telemetry.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.common import vortex_telemetry_contexts_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__telemetry__contexts__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/metadata_telemetry.proto\x12#v1.public.events.metadata_telemetry\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a>dbtlabs/proto/public/v1/common/vortex_telemetry_contexts.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\"\xa6\x02\n\x07Handoff\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12[\n\x07\x63ontext\x18\x02 \x01(\x0b\x32J.v1.public.common.vortex_telemetry_contexts.VortexTelemetryDbtCloudContext\x12\x14\n\x0chandoff_from\x18\x03 \x01(\t\x12\x12\n\nhandoff_to\x18\x04 \x01(\t\x12\x1f\n\x17is_final_handoff_action\x18\x05 \x01(\x08\x12\x16\n\x0ehandoff_action\x18\x06 \x01(\t\x12\x12\n\nasset_type\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01*E\n\x0bHandoffFrom\x12\x1c\n\x18HANDOFF_FROM_UNSPECIFIED\x10\x00\x12\x18\n\x14HANDOFF_FROM_CATALOG\x10\x01*\x83\x01\n\tHandoffTo\x12\x1a\n\x16HANDOFF_TO_UNSPECIFIED\x10\x00\x12\x16\n\x12HANDOFF_TO_CATALOG\x10\x01\x12\x12\n\x0eHANDOFF_TO_IDE\x10\x02\x12\x15\n\x11HANDOFF_TO_CANVAS\x10\x03\x12\x17\n\x13HANDOFF_TO_INSIGHTS\x10\x04*\xe5\x02\n\x10HandoffAssetType\x12\"\n\x1eHANDOFF_ASSET_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cHANDOFF_ASSET_TYPE_DBT_MODEL\x10\x01\x12!\n\x1dHANDOFF_ASSET_TYPE_DBT_SOURCE\x10\x02\x12#\n\x1fHANDOFF_ASSET_TYPE_DBT_SNAPSHOT\x10\x03\x12\x1f\n\x1bHANDOFF_ASSET_TYPE_DBT_SEED\x10\x04\x12!\n\x1dHANDOFF_ASSET_TYPE_DBT_METRIC\x10\x05\x12&\n\"HANDOFF_ASSET_TYPE_DBT_SAVED_QUERY\x10\x06\x12+\n\'HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_TABLE\x10\x07\x12*\n&HANDOFF_ASSET_TYPE_DATA_WAREHOUSE_VIEW\x10\x08\x42\x46ZDgithub.com/dbt-labs/proto-golang/v1/public/events/metadata_telemetryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.metadata_telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZDgithub.com/dbt-labs/proto-golang/v1/public/events/metadata_telemetry'
  _globals['_HANDOFF']._loaded_options = None
  _globals['_HANDOFF']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_HANDOFFFROM']._serialized_start=555
  _globals['_HANDOFFFROM']._serialized_end=624
  _globals['_HANDOFFTO']._serialized_start=627
  _globals['_HANDOFFTO']._serialized_end=758
  _globals['_HANDOFFASSETTYPE']._serialized_start=761
  _globals['_HANDOFFASSETTYPE']._serialized_end=1118
  _globals['_HANDOFF']._serialized_start=259
  _globals['_HANDOFF']._serialized_end=553
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class EventInfo(google.protobuf.message.Message):
    """Common event info"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PID_FIELD_NUMBER: builtins.int
    THREAD_FIELD_NUMBER: builtins.int
    TS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    name: builtins.str
    code: builtins.str
    msg: builtins.str
    level: builtins.str
    invocation_id: builtins.str
    pid: builtins.int
    thread: builtins.str
    category: builtins.str
    @property
    def ts(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def extra(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        code: builtins.str = ...,
        msg: builtins.str = ...,
        level: builtins.str = ...,
        invocation_id: builtins.str = ...,
        pid: builtins.int = ...,
        thread: builtins.str = ...,
        ts: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        extra: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        category: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ts", b"ts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["category", b"category", "code", b"code", "extra", b"extra", "invocation_id", b"invocation_id", "level", b"level", "msg", b"msg", "name", b"name", "pid", b"pid", "thread", b"thread", "ts", b"ts"]) -> None: ...

Global___EventInfo: typing_extensions.TypeAlias = EventInfo

@typing.final
class GenericMessage(google.protobuf.message.Message):
    """GenericMessage, used for deserializing only"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["info", b"info"]) -> None: ...

Global___GenericMessage: typing_extensions.TypeAlias = GenericMessage

@typing.final
class BehaviorChangeEvent(google.protobuf.message.Message):
    """D - Deprecations

    D018
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLAG_NAME_FIELD_NUMBER: builtins.int
    FLAG_SOURCE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DOCS_URL_FIELD_NUMBER: builtins.int
    flag_name: builtins.str
    flag_source: builtins.str
    description: builtins.str
    docs_url: builtins.str
    def __init__(
        self,
        *,
        flag_name: builtins.str = ...,
        flag_source: builtins.str = ...,
        description: builtins.str = ...,
        docs_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "docs_url", b"docs_url", "flag_name", b"flag_name", "flag_source", b"flag_source"]) -> None: ...

Global___BehaviorChangeEvent: typing_extensions.TypeAlias = BehaviorChangeEvent

@typing.final
class BehaviorChangeEventMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___BehaviorChangeEvent: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___BehaviorChangeEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___BehaviorChangeEventMsg: typing_extensions.TypeAlias = BehaviorChangeEventMsg

@typing.final
class GetMetaKeyDeprecation(google.protobuf.message.Message):
    """D041"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_KEY_FIELD_NUMBER: builtins.int
    meta_key: builtins.str
    def __init__(
        self,
        *,
        meta_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["meta_key", b"meta_key"]) -> None: ...

Global___GetMetaKeyDeprecation: typing_extensions.TypeAlias = GetMetaKeyDeprecation

@typing.final
class GetMetaKeyDeprecationMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___GetMetaKeyDeprecation: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___GetMetaKeyDeprecation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GetMetaKeyDeprecationMsg: typing_extensions.TypeAlias = GetMetaKeyDeprecationMsg

@typing.final
class RetryExternalCall(google.protobuf.message.Message):
    """M - Deps generation

    M020
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTEMPT_FIELD_NUMBER: builtins.int
    MAX_FIELD_NUMBER: builtins.int
    attempt: builtins.int
    max: builtins.int
    def __init__(
        self,
        *,
        attempt: builtins.int = ...,
        max: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["attempt", b"attempt", "max", b"max"]) -> None: ...

Global___RetryExternalCall: typing_extensions.TypeAlias = RetryExternalCall

@typing.final
class RetryExternalCallMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___RetryExternalCall: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___RetryExternalCall | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RetryExternalCallMsg: typing_extensions.TypeAlias = RetryExternalCallMsg

@typing.final
class RecordRetryException(google.protobuf.message.Message):
    """M021"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXC_FIELD_NUMBER: builtins.int
    exc: builtins.str
    def __init__(
        self,
        *,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc"]) -> None: ...

Global___RecordRetryException: typing_extensions.TypeAlias = RecordRetryException

@typing.final
class RecordRetryExceptionMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___RecordRetryException: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___RecordRetryException | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RecordRetryExceptionMsg: typing_extensions.TypeAlias = RecordRetryExceptionMsg

@typing.final
class GetMetaKeyWarning(google.protobuf.message.Message):
    """Q - Node execution

    Q047
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_KEY_FIELD_NUMBER: builtins.int
    meta_key: builtins.str
    def __init__(
        self,
        *,
        meta_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["meta_key", b"meta_key"]) -> None: ...

Global___GetMetaKeyWarning: typing_extensions.TypeAlias = GetMetaKeyWarning

@typing.final
class GetMetaKeyWarningMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___GetMetaKeyWarning: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___GetMetaKeyWarning | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___GetMetaKeyWarningMsg: typing_extensions.TypeAlias = GetMetaKeyWarningMsg

@typing.final
class SystemCouldNotWrite(google.protobuf.message.Message):
    """Z - Misc

    Z005
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    EXC_FIELD_NUMBER: builtins.int
    path: builtins.str
    reason: builtins.str
    exc: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        reason: builtins.str = ...,
        exc: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["exc", b"exc", "path", b"path", "reason", b"reason"]) -> None: ...

Global___SystemCouldNotWrite: typing_extensions.TypeAlias = SystemCouldNotWrite

@typing.final
class SystemCouldNotWriteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemCouldNotWrite: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemCouldNotWrite | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemCouldNotWriteMsg: typing_extensions.TypeAlias = SystemCouldNotWriteMsg

@typing.final
class SystemExecutingCmd(google.protobuf.message.Message):
    """Z006"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CMD_FIELD_NUMBER: builtins.int
    @property
    def cmd(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        cmd: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cmd", b"cmd"]) -> None: ...

Global___SystemExecutingCmd: typing_extensions.TypeAlias = SystemExecutingCmd

@typing.final
class SystemExecutingCmdMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemExecutingCmd: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemExecutingCmd | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemExecutingCmdMsg: typing_extensions.TypeAlias = SystemExecutingCmdMsg

@typing.final
class SystemStdOut(google.protobuf.message.Message):
    """Z007"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BMSG_FIELD_NUMBER: builtins.int
    bmsg: builtins.str
    def __init__(
        self,
        *,
        bmsg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bmsg", b"bmsg"]) -> None: ...

Global___SystemStdOut: typing_extensions.TypeAlias = SystemStdOut

@typing.final
class SystemStdOutMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemStdOut: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemStdOut | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemStdOutMsg: typing_extensions.TypeAlias = SystemStdOutMsg

@typing.final
class SystemStdErr(google.protobuf.message.Message):
    """Z008"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BMSG_FIELD_NUMBER: builtins.int
    bmsg: builtins.str
    def __init__(
        self,
        *,
        bmsg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bmsg", b"bmsg"]) -> None: ...

Global___SystemStdErr: typing_extensions.TypeAlias = SystemStdErr

@typing.final
class SystemStdErrMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemStdErr: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemStdErr | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemStdErrMsg: typing_extensions.TypeAlias = SystemStdErrMsg

@typing.final
class SystemReportReturnCode(google.protobuf.message.Message):
    """Z009"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETURNCODE_FIELD_NUMBER: builtins.int
    returncode: builtins.int
    def __init__(
        self,
        *,
        returncode: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["returncode", b"returncode"]) -> None: ...

Global___SystemReportReturnCode: typing_extensions.TypeAlias = SystemReportReturnCode

@typing.final
class SystemReportReturnCodeMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___SystemReportReturnCode: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___SystemReportReturnCode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___SystemReportReturnCodeMsg: typing_extensions.TypeAlias = SystemReportReturnCodeMsg

@typing.final
class Formatting(google.protobuf.message.Message):
    """Z017"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___Formatting: typing_extensions.TypeAlias = Formatting

@typing.final
class FormattingMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___Formatting: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___Formatting | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___FormattingMsg: typing_extensions.TypeAlias = FormattingMsg

@typing.final
class Note(google.protobuf.message.Message):
    """Z050"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___Note: typing_extensions.TypeAlias = Note

@typing.final
class NoteMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___Note: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___Note | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___NoteMsg: typing_extensions.TypeAlias = NoteMsg

@typing.final
class PrintEvent(google.protobuf.message.Message):
    """Z052"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___PrintEvent: typing_extensions.TypeAlias = PrintEvent

@typing.final
class PrintEventMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___PrintEvent: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___PrintEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___PrintEventMsg: typing_extensions.TypeAlias = PrintEventMsg

@typing.final
class RecordReplayIssue(google.protobuf.message.Message):
    """Z053"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MSG_FIELD_NUMBER: builtins.int
    msg: builtins.str
    def __init__(
        self,
        *,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["msg", b"msg"]) -> None: ...

Global___RecordReplayIssue: typing_extensions.TypeAlias = RecordReplayIssue

@typing.final
class RecordReplayIssueMsg(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> Global___EventInfo: ...
    @property
    def data(self) -> Global___RecordReplayIssue: ...
    def __init__(
        self,
        *,
        info: Global___EventInfo | None = ...,
        data: Global___RecordReplayIssue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["data", b"data", "info", b"info"]) -> None: ...

Global___RecordReplayIssueMsg: typing_extensions.TypeAlias = RecordReplayIssueMsg
